setMethod("readFlowJoFile",
          signature(xmlFile = "character"), 
          definition = function(xmlFile) {
  
    ## Check whether the FlowJo workspace exists.  
    if (! file.exists(xmlFile)) {
      stop(paste("I don't see a file at:", xmlFile)); 
    }
     
    ## Initial load of XML data file in as a text file.   It turns out that the
    ## XML for versions 7.5.0 --> 7.6 are malformed and I need to add the namespace
    ## material into the data.
    xmlText       <- scan(file=xmlFile, what="character", sep="\n", quiet=TRUE)
    xmlText       <- iconv(xmlText, sub=NA_character_)
    flowJoVersion <- xmlText[grep("flowJoVersion", xmlText)]
    flowJoVersion <- gsub(".*flowJoVersion=\"([^\"]*).*", "\\1", flowJoVersion)
    flowJoVersion <- gsub("^\\D*",   "",  flowJoVersion, perl=TRUE);
    flowJoVersion <- gsub("\\D{1,}", "\\.", flowJoVersion, perl=TRUE);
    xmlText       <- paste(xmlText, collapse="\n")
    nsFound       <- length(grep("xmlns:gating", xmlText)) > 0
    
    ## Thus here I stuff in the nameSpace information  
    if ((compareVersion(flowJoVersion, "7.4.9") > 0) && (!nsFound)) { 
       
      nameSpaceDefinitions <- 'xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" 
xmlns:gating="http://www.isac-net.org/std/Gating-ML/v1.5/gating" 
xmlns:transforms="http://www.isac-net.org/std/Gating-ML/v1.5/transformations" 
xmlns:data-type="http://www.isac-net.org/std/Gating-ML/v1.5/datatypes" 
xsi:schemaLocation="http://www.isac-net.org/std/Gating-ML/v1.5/gating ../../XML-schemas/Gating-ML.v1.5.xsd http://www.isac-net.org/std/Gating-ML/v1.5/transformations ../../XML-schemas/Transformations.v1.5.xsd http://www.isac-net.org/std/Gating-ML/v1.5/datatypes ../../XML-schemas/DataTypes.v1.5.xsd"'
    
      nameSpaceDefinitions = gsub("\n", "", nameSpaceDefinitions)   
      xmlText = gsub("<Workspace (.*)", paste("<Workspace ", nameSpaceDefinitions, "\\1"), xmlText)   
#      cat(xmlText, file=paste(wspLocations, "fixed.wsp", sep=''))
    }  
    
    ## Now finally read the workspace in as a DOM object
    flowJoDOM <- xmlTreeParse(xmlText, useInternalNodes=TRUE, 
                              error = xmlErrorCumulator(class = "XMLParserErrorList", 
                                                        immediate = FALSE))
    docName(flowJoDOM) <- xmlFile
  
  
    ## Get the root of the DOM tree; expect it to be a "Workspace" node
    root <- xmlRoot(flowJoDOM);
    if(xmlName(root) != "Workspace") {
      stop("Top node is not a 'Workspace' node.  Is this really a FlowJo workspace?!?");
    }
  
    ## This Workspace should refer to at least one or more FCS files
    numSamples = length(xpathApply(flowJoDOM,
                                   path="/Workspace/SampleList/Sample/DataSet",
                                   xmlChildren));
                                   
    if (numSamples < 1) {
      warning("This workspace doesn't refer to any FCS files!");
    }

    numGates = length(xpathApply(flowJoDOM,
                                 path="/Workspace/SampleList/Sample/SampleNode/Subpopulations",
                                 xmlChildren));
                                   
    if (numGates < 1) {
      warning("This workspace doesn't contain any gates!");
    }
    
    return(flowJoDOM);            
});




