\name{getFlowJoGates}
\alias{getFlowJoGates}
\alias{getFlowJoGates,flowJoObj-method}
\alias{getFlowJoGates,flowJoList-method}
\alias{getFlowJoGates,flowJoObj,character-method}
\alias{getFlowJoGates,flowJoList,character-method}


\title{ getFlowJoGates }
\description{
  Given a parsed FlowJo workspace (flowJoObj) or list of FlowJo workspaces (flowJoList), return an indexed list of the gates, as flowCore style filter objects, for each of the FCS files.  Also get the associated compensation matrices.
}
\usage{
getFlowJoGates(fj, fileNamePatterns)
}

\arguments{
  \item{fj}{ a flowJoList or flowJoObj }
  \item{fileNamePatterns}{ a vector of one or more patterns used to pick specific FCS files from the complete list of FCS files (with their paths) listed in the FlowJo workspace(s).  The default is \dQuote{.} -- ie all of the FCS files will be chosen. }
}

\value{
The method getFlowJoGates returns a list of ordered lists which includes references to a set of FCS files, their locations, all gating structures related to them (as flowCore filter objects), the names of those gates (filters), and the associated compensation matrices for the FCS files.  
}


\author{ John Gosink }
\seealso{ See also FlowJo from TreeStar Inc, at:  \url{http://www.flowjo.com/} }

\examples{

# Note this may take a moment to process the whole XML file
library(flowFlowJo);
demoLocation <- system.file("extdata", "DemoWorkspace.wsp", package="flowFlowJo"); 
actualFCSLoc <- system.file("extdata/fcsFiles", package="flowFlowJo"); 
testList     <- readFlowJoList(demoLocation, altFileLocation=actualFCSLoc);
z            <- getFlowJoGates(testList, fileNamePatterns=c("A01"));

}

