\name{simplifyGateNames} 
\alias{simplifyGateNames} 
\alias{simplifyGateNames,character-method} 
\alias{simplifyGateNames,filter-method} 

\title{ Standardize flow cytometry gate names } 
\description{ 
 This function helps to standardize typical flow cytometry cell population names. This is useful when trying to combine the results from a large number of flow runs wherein the cytometrist may have used slightly different nomenclature to describe the same set of cells.   For example, "Lymphocytes" vs. "lymphoctes". 
} 
\usage{ 
simplifyGateNames(x, \dots) 
} 

\arguments{ 
 \item{x}{ Logical.  Default=FALSE.  A flowCore style filter, or a text string with a gate (filter) name } 
 \item{\dots}{ Additional arguments: 	
 	\emph{upperCaseGates} Logical.  Default=FALSE.  If TRUE, convert the gate names to all upper case    \cr
	\emph{stripFileName}  Logical.  Default=TRUE.  It is currently the convention that the flowFlowJo code prepends the name of the referenced FCS file within the gate name, followed by a colon, then the rest of the gate information.  This setting looks for ".*\\.fcs:" and strips it out of the gate name   \cr 
	\emph{removeParentalNames} Logical.  Default=TRUE.  The current \emph{getFlowJoGates} method concatenates a gate's name with the name of all of it's parents.  \cr 
     }   
} 

\value{ 
 This function returns either a text string or flowCore style filter object. 
} 

\author{ John Gosink } 


\examples{ 
simplifyGateNames(c("LymphoCytes", "lymphocytes", "mOnOcYtEs"));
simplifyGateNames(c("Lymphocytes:CD8+"), removeParentalNames=TRUE); 
simplifyGateNames("CD34 positive cells ") 
simplifyGateNames("CD34 + ") 
}

\keyword{methods}
\keyword{list}

